@@ -1,7 +1,11 @@
-"""Modulo que contiene la clase que representa la metaheuristica de Algoritmo Genetico"""
+"""
+Modulo que contiene la clase que representa la metaheuristica de Algoritmo Genetico
 
+"""
+
+from ..Tools import utilities, bcolors, plot, Trajectory
 from . import Population, csv, datetime, Path, timer, PrettyTable, path
-from .. import Tour, Tsp, AlgorithmsOptions, SelectionStrategy, plot, bcolors, Trajectory, utilities
+from .. import Tour, Tsp, AlgorithmsOptions, SelectionStrategy
 
 class GeneticAlgorithm():
     """ Clase Simulated Annealing la cual representa dicha metaheristica y sus metodos de busqueda
@@ -137,9 +141,15 @@ class GeneticAlgorithm():
             self.best_tour.copy(population.getBestTour())
         
         # Guardar trayectoria
-        self.trajectory.append( Trajectory(self.best_tour.current.copy(),
-                                self.best_tour.cost, 0, self.evaluations,
-                                population.getAverage(), population.getDeviation()) ) 
+        self.trajectory.append( Trajectory(tour=self.best_tour.current.copy(),
+                                cost=self.best_tour.cost, iterations=0, evaluations=self.evaluations,
+                                average=population.getAverage(), deviation=population.getDeviation(),
+                                worst=population.getWorstTour().cost) )
+        if not self.options.replit:
+            self.trajectory.append( Trajectory(tour=self.best_tour.current.copy(),
+                                    cost=self.best_tour.cost, iterations=0, evaluations=self.evaluations,
+                                    average=population.getAverage(), deviation=population.getDeviation(),
+                                    worst=population.getWorstTour().cost) )
         self.evaluations += self.offspring_size
 
         # tiempo para iteraciones y condicion de termino por tiempo
@@ -176,9 +186,11 @@ class GeneticAlgorithm():
                     
                 self.best_tour.copy(offspring.getBestTour())
                 # Guardar trayectoria
-                self.trajectory.append( Trajectory(self.best_tour.current.copy(),
-                                        self.best_tour.cost, self.iterations, self.evaluations,
-                                        population.getAverage(), population.getDeviation()) ) 
+                # Guardar trayectoria
+                self.trajectory.append( Trajectory(tour=self.best_tour.current.copy(),
+                                        cost=self.best_tour.cost, iterations=self.iterations, evaluations=self.evaluations,
+                                        average=population.getAverage(), deviation=population.getDeviation(),
+                                        worst=population.getWorstTour().cost) ) 
                 
             else: 
                 #if not self.options.silent:
@@ -301,9 +313,9 @@ class GeneticAlgorithm():
             })
     
 
-    def visualize(self, replit: bool) -> None:
-        """ Visualiza la trayectoria de la solucion"""
-        plot.replit = replit
-        plot.trajectory = self.trajectory
-        plot.show()
-        
\ No newline at end of file
+    def visualize(self) -> None:
+        """ Visualiza la trayectoria de la solucion """
+        plot.Graph.replit = self.options.replit
+        plot.Graph.trajectory = self.trajectory
+        
+        plot.show(self.options.gui)
\ No newline at end of file
