@@ -1,4 +1,7 @@
-"""Paquete que contiene los algoritmos con las metaheristicas de simulated annealing y algoritmo genetico"""
+""" 
+Paquete que contiene los algoritmos con los distintos metodos de busqueda para solucionar problemas TSP
+
+"""
 
 import csv
 import math
@@ -11,4 +14,6 @@ from prettytable import PrettyTable
 
 from src.tspf.Algorithms.Population import Population
 from src.tspf.Algorithms.GeneticAlgorithm import GeneticAlgorithm
-from src.tspf.Algorithms.SimulatedAnnealing import SimulatedAnnealing
\ No newline at end of file
+from src.tspf.Algorithms.SimulatedAnnealing import SimulatedAnnealing
+from src.tspf.Algorithms.LocalSearch import LocalSearch
+from src.tspf.Algorithms.IteratedLocalSearch import IteratedLocalSearch
\ No newline at end of file
